==> material-ui-shell-1.1.9.tgz: package/es/providers/Filter/store/actions.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as types from './types';
export function setFilterIsOpen(name, isOpen) {
  return {
    type: types.ON_FILTER_OPEN_CHANGED,
    name,
    payload: {
      isOpen
    }
  };
}
export function clearFilter(name, isOpen) {
  return {
    type: types.ON_CLEAR,
    name
  };
}
export function setFields(name, fields) {
  return {
    type: types.ON_SET_FIELDS,
    name,
    payload: {
      fields
    }
  };
}
export function setFilterSortField(name, sortField) {
  return {
    type: types.ON_FILTER_SORT_FIELD_CHANGED,
    name,
    payload: {
      sortField
    }
  };
}
export function setFilterSortOrientation(name, sortOrientation) {
  return {
    type: types.ON_FILTER_SORT_FIELD_CHANGED,
    name,
    payload: {
      sortOrientation
    }
  };
}
export function addFilterQuery(name, query) {
  return {
    type: types.ON_ADD_FILTER_QUERY,
    name,
    payload: _extends({}, query)
  };
}
export function setSearch(name, search) {
  return {
    type: types.ON_SET_SEARCH,
    name,
    payload: search
  };
}
export function editFilterQuery(name, index, query) {
  return {
    type: types.ON_EDIT_FILTER_QUERY,
    name,
    index,
    payload: _extends({}, query)
  };
}
export function removeFilterQuery(name, index) {
  return {
    type: types.ON_REMOVE_FILTER_QUERY,
    name,
    index
  };
}

==> material-ui-shell-1.1.12.tgz: package/es/providers/Filter/store/actions.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as types from './types';
export function openFilter(name) {
  return {
    type: types.ON_FILTER_IS_OPEN,
    name,
    payload: {
      isOpen: true
    }
  };
}
export function closeFilter(name) {
  return {
    type: types.ON_FILTER_IS_CLOSE,
    name,
    payload: {
      isOpen: false
    }
  };
}
export function clearFilter(name, isOpen) {
  return {
    type: types.ON_CLEAR,
    name
  };
}
export function setFilterSortField(name, sortField) {
  return {
    type: types.ON_FILTER_SORT_FIELD_CHANGED,
    name,
    payload: {
      sortField
    }
  };
}
export function setScrollOffset(name, scrollOffset) {
  return {
    type: types.ON_SET_SCROLL_OFFSET,
    name,
    payload: {
      scrollOffset
    }
  };
}
export function setFilterSortOrientation(name, sortOrientation) {
  return {
    type: types.ON_FILTER_SORT_FIELD_CHANGED,
    name,
    payload: {
      sortOrientation
    }
  };
}
export function addFilterQuery(name, query) {
  return {
    type: types.ON_ADD_FILTER_QUERY,
    name,
    payload: _extends({}, query)
  };
}
export function setSearch(name, search) {
  return {
    type: types.ON_SET_SEARCH,
    name,
    payload: search
  };
}
export function editFilterQuery(name, index, query) {
  return {
    type: types.ON_EDIT_FILTER_QUERY,
    name,
    index,
    payload: _extends({}, query)
  };
}
export function removeFilterQuery(name, index) {
  return {
    type: types.ON_REMOVE_FILTER_QUERY,
    name,
    index
  };
}
